@@ -13,13 +13,23 @@ use strict;
 use Term::ANSIColor;
 use Log::Fast;
 use Time::HiRes qw(time);
-use Data::Dumper::Simple;
+use Data::Printer {
+      'alias'          => 'Dumper',
+      'use_prototypes' => 0,
+      'colored'        => 1,
+      'hash_separator' => ' => ',
+      'indent'         => 3,
+      'deparse'        => 1,
+      'class'          => {
+          'expand' => 'all'
+      },
+};
 
 BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 0.12;
+    our $VERSION = 0.20;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -440,6 +450,7 @@ sub debug {
     my $nested = do {my $n = 0; 1 while caller(2 + $n++); ' ' x $n};    # add padding to nested lines
     my $first = 1;                                                      # Set the first line flag.
     foreach my $msg (@messages) {                                       # Loop through each line of output and format accordingly.
+        $msg = Dumper($msg) if (ref($msg) ne '');
         if ($msg =~ /\n/s) {                                            # If the line contains newlines, then it too must be split into multiple lines.
             my @message = split(/\n/, $msg);
             foreach my $line (@message) {                               # Loop through the split lines and format accordingly.
@@ -493,6 +504,22 @@ sub _send_to_logger {    # This actually simplifies the previous class
     }
 } ## end sub send_to_logger
 
+=head1 INSTALLATION
+
+To install this module, run the following commands:
+
+ perl Build.PL
+ ./Build
+ ./Build test
+ ./Build install
+
+OR you can use the old ExtUtils::MakeMaker method:
+
+ perl Makefile.PL
+ make
+ make test
+ make install
+
 =head1 AUTHOR
 
 Richard Kelsch <rich@rk-internet.com>
@@ -504,7 +531,7 @@ modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-Version 0.12    (November 27, 2014)
+Version 0.20    (March 21, 2015)
 
 =head1 BUGS
 
